@@ -29,5 +29,7 @@ def mustacheich(parser, token):
     bits = token.contents.split()
     if len(bits) not in [2, 3]:
         raise template.TemplateSyntaxError(
-            "'mustacheraw' tag takes one argument: the name/id of the template")
-    return MustacheICanHazNode(bits[1])
+            "'mustacheich' tag takes either (1) one argument: the name/id of "
+            "the template, or (2)  two arguments: the name of a subdirectory "
+            "to search and a regular expression of files to search for")
+    return MustacheICanHazNode(*bits[1:])
